Getting Started as a Contributor
================================

Contributions to the Font Bakery source code and documentation are welcomed! Please read
and follow the instructions below to get started.

Getting Started
---------------

The project is run on Github, in the
`typical <http://producingoss.com>`__ free software way. We’d love to
accept your patches and contributions to this project. There are a few
guidelines you need to follow to make that happen.

We use Github’s Issue Tracker to report and track bugs, map out future
improvements, set priorities and assign people to them. We only assign
an issue to someone when they are going to work on that issue soon. We
tag all issues with a priority tag, P0 for “urgent” through P5 for
“someday-maybe”. If you find a bug or have an idea, please `create a new
issue <https://github.com/fonttools/fontbakery/issues/new>`__ and
we’ll be happy to work with you on it!

If you would like to contribute your work on the project source, please
review the following and continue to the appropriate section of the 
documentation to learn how to set up a development environment and 
propose changes to this project.

Accept the Google Contributor License Agreement
-----------------------------------------------

Contributions to this project must be accompanied by a Contributor
License Agreement (CLA). You (or your employer) retain the copyright to
your contribution this simply gives us permission to use and
redistribute your contributions as part of the project. Head over to
https://cla.developers.google.com/ to sign an agreement.

You generally only need to submit a CLA once, so if you’ve already
submitted one (even if it was for a different project), you probably
don’t need to do it again.

After your contribution is included, you will be listed in the
`CONTRIBUTORS.txt <https://github.com/fonttools/fontbakery/blob/main/CONTRIBUTORS.txt>`__
and/or
`AUTHORS.txt <https://github.com/fonttools/fontbakery/blob/main/AUTHORS.txt>`__
files. ``CONTRIBUTORS.txt`` is the official list of people who can
contribute (and typically have contributed) code to this repository,
while the ``AUTHORS.txt`` file lists the copyright holders.

Go!
---

Read the :doc:`source-contrib-guide` to learn how to set up a development environment for
source code contributions or the :doc:`doc-contrib-guide` to learn how to improve our 
documentation.
